zpz
===

This packages collects some small Python utilities that I (owner of the Github account "zpz")
have created in practice.

These utilities are not "one-off" experiments; they are really useful code.
However, the utilities do not form a coherent set of utilities for a particular application domain.
There is no plan to maintain this code as a coherent library.
The recommended way to use it is to copy-paste whatever segments you find useful.

This package is uploaded to [Pypi](https://pypi.org/search/?q=zpz). However, consider it to be mainly for the author's personal convenience and exercise. Do not assume the upload will be maintained in a stable and backward-compatible way. At present, the package installer does not install its dependencies.

The version is year-based. For example, "0.18.0" is the first release in 2018.
